// RFID Library Gemaakt door Miguel Balboa (circuitito.com)

#include <SPI.h>
#include <RFID.h>
#include <Servo.h>
#include "pitches.h"
#include <Wire.h>
RFID rfid(10, 5); // Definieer de RFID
// Vervang dit door de code van jouw kaart in hexadecimale vorm
byte card[5] = {0x4D, 0x55, 0xAD, 0xD3, 0x66};
// Som hier andere codes op van kaarten die toegang hebben
byte serNum[5];
byte data[5];
// Definieer de melodieën voor succesvolle en geweigerde toegang
int access_melody[] = {NOTE_G4, 0, NOTE_A4, 0, NOTE_B4, 0, NOTE_A4,
                       0, NOTE_B4, 0, NOTE_C5, 0
                      };
int access_noteDurations[] = {8, 8, 8, 8, 8, 4, 8, 8, 8, 8, 8, 4};
int fail_melody[] = {NOTE_G2, 0, NOTE_F2, 0, NOTE_D2, 0};
int fail_noteDurations[] = {8, 8, 8, 8, 8, 4};
int LED_access = 2; // Pen verbonden met groene ledje
int LED_intruder = 3; // Pen verbonden met rode ledje
int speaker_pin = 8; // Pen verbonden met piëzo zoemer
int servoPin = 9; // Pen verbonden met servo
Servo doorLock; // Definieer de servo-motor
void setup() {
  doorLock.attach(servoPin); // Stel servo in als een pen
  Serial.begin(9600); // Start seriële communicatie
  SPI.begin(); // Start seriële communicatie tussen de RFID en PC
  rfid.init(); // Initialiseer de RFID
  Serial.println("Arduino card reader");
  delay(1000);
  pinMode(LED_access, OUTPUT);
  pinMode(LED_intruder, OUTPUT);
  pinMode(speaker_pin, OUTPUT);
  pinMode(servoPin, OUTPUT);
}
void loop() { // Creëer een variabele voor elke gebruiker
  boolean card_card = true; // Definieer je kaart
  if (rfid.isCard()) {
    if (rfid.readCardSerial()) {
      delay(1000);
      data[0] = rfid.serNum[0];
      data[1] = rfid.serNum[1];
      data[2] = rfid.serNum[2];
      data[3] = rfid.serNum[3];
      data[4] = rfid.serNum[4];
    }
    Serial.print("Card found - code:");
    for (int i = 0; i < 5; i++) {
      // Als het niet jouw kaart is, dan wordt de kaart als onjuist beschouwd
      if (data[i] != card[i]) card_card = false;
    }
    Serial.println();
    if (card_card) { // Er is een kaart met toestemming voor toegang gevonden
      Serial.println("Hello Mark!"); // Toon in Seriële Monitor
      for (int i = 0; i < 12; i++) { // Speel welkomstmuziek af
        int access_noteDuration = 1000 / access_noteDurations[i];
        tone(speaker_pin, access_melody[i], access_noteDuration);
        int access_pauseBetweenNotes = access_noteDuration * 1.30;
        delay(access_pauseBetweenNotes);
        noTone(speaker_pin);
      }
    }
    else { // Als de kaart niet wordt herkend
      // Toon bericht in Seriële Monitor
      Serial.println("Card not recognized! Contact administrator!");
      digitalWrite(LED_intruder, HIGH); // Zet rood ledje aan
      for (int i = 0; i < 6; i++) { // Speel indringer-melodie af
        int fail_noteDuration = 1000 / fail_noteDurations[i];
        tone(speaker_pin, fail_melody[i], fail_noteDuration);
        int fail_pauseBetweenNotes = fail_noteDuration * 1.30;
        delay(fail_pauseBetweenNotes);
        noTone(speaker_pin);
      }
      delay(1000);
      digitalWrite(LED_intruder, LOW); // Zet rode ledje uit
    }
    if (card_card) { // Voeg hier andere gebruikers met toegang toe
      Serial.println("Access granted.......Welcome!");
      digitalWrite(LED_access, HIGH); // Zet groene ledje aan
      doorLock.write(180); // Draai servo 180 graden
      delay(5000); // Wacht 5 seconden
      doorLock.write(0); // Draai servo terug naar 0 graden
      digitalWrite(LED_access, LOW); // Zet groene ledje uit
    }
    Serial.println();
    delay(500);
    rfid.halt();
  }
}
